# Twitch VOD
Tool to retrieve Twitch's VOD from the video ID

## Install

## Use
1. Execute the tool from a terminal 
```bash
tvod
```

2. It will ask the video ID (you can find it in twitch's video page). In this (`https://www.twitch.tv/videos/1234567890`) case the ID is `1234567890`

3. It will ask at which resolution watch

4. It will use your browser to watch it.
